summaryrefslogtreecommitdiff
path: root/def.go
diff options
context:
space:
mode:
Diffstat (limited to 'def.go')
-rw-r--r--def.go8
1 files changed, 6 insertions, 2 deletions
diff --git a/def.go b/def.go
index 9a9758c..8b90244 100644
--- a/def.go
+++ b/def.go
@@ -123,14 +123,18 @@ const (
TextRenderingModeFill = 0
// TextRenderingModeStroke strokes text
TextRenderingModeStroke = 1
- // TextRenderingModeFillThenStroke fills then strokes text
- TextRenderingModeFillThenStroke = 2
+ // TextRenderingModeFillStroke fills then strokes text
+ TextRenderingModeFillStroke = 2
// TextRenderingModeInvisible neither fills nor strokes text
TextRenderingModeInvisible = 3
// TextRenderingFillClip fills text and add to path for clipping
TextRenderingModeFillClip = 4
// TextRenderingFillClip strokes text and add to path for clipping
TextRenderingModeStrokeClip = 5
+ // TextRenderingModeFillStrokeClip fills then strokes text and add to path for clipping
+ TextRenderingModeFillStrokeClip = 6
+ // TextRenderingModeClip Adds text to path for clipping
+ TextRenderingModeClip = 7
)
type colorMode int